#! /usr/bin/python
# -*- coding: utf-8 -*-

from xml.sax import handler

from importer.unification import UnifiedFrameImport


class XMLNode:
    
    def __init__(self, name, attrs, parent):
        self._name = name
        self._attrs = attrs
        self._children = []
        self._parent = parent
        self._content = ""

    def addChild(self, child):
        self._children.append(child)

    def setContent(self, content):
        self._content = content

    def __str__(self):
        att = zip(self._attrs.keys(), self._attrs.values())
        return self._name + '[' + str(att) + '](' + ';'.join([str(temp) for temp in self._children]) + ')'


class UnificationPreprocessHandler(handler.ContentHandler):

    def __init__(self):
        handler.ContentHandler.__init__(self)
        self._subtree = None
        self._current = None
        self._constructing = False
        self._content = ""
        self.entry_meanings = {}
        self.meanings = {}
        self.frames = {}
        
    def startElement(self, name, attrs):
        if name == 'date':
            pass
        if name == 'unifier_frame':
            self._constructing = True
            self._content = ""
        if (self._constructing):
            node = XMLNode(name, attrs, self._current)
            if self._current is not None:
                self._current.addChild(node)
            else:
                self._subtree = node
            self._current = node

    def endElement(self, name):
        if self._current is not None:
            self._current.setContent(self._content.strip())
            self._current = self._current._parent
            if name == 'unifier_frame':
                UnifiedFrameImport.UnifiedFrameImport.storeUnifiedFrame(self._subtree)
            self._content = ''

    def characters(self, content):
        self._content += content
        

